<?php
/**
 * Provides functions for the plugin settings page in the WordPress admin.
 *
 * Settings can be accessed at WooCommerce -> Settings -> Accounting Hub.
 *
 * @package   WooCommerce_Accounting_Report
 * @author    BjornTech <info@bjorntech.se>
 * @license   GPL-3.0
 * @link      http://bjorntech.se
 * @copyright 2017-2018 BjornTech - BjornTech AB
 * 
 * Text Domain:       woo-accounting-report
 */
// Prevent direct file access
if (!defined('ABSPATH')) {
    exit;
}

if (class_exists('WC_Admin_Accounting_Report_Settings', false)) {
 //  return new WC_Admin_Accounting_Report_Settings();
}

/**
 * WC_Admin_Accounting_Report_Settings.
 */
class WC_Admin_Accounting_Report_Settings 
{

    const SETTINGS_TAB = 'accounting_report';

    /**
     * Constructor.
     */
    public function __construct()
    {
        add_filter('woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50);
        add_action('woocommerce_settings_' . self::SETTINGS_TAB, __CLASS__ . '::settings_tab');
        add_action('woocommerce_update_options_' . self::SETTINGS_TAB, __CLASS__ . '::update_settings');
    }
    
    public static function add_settings_tab($settings_tabs)
    {
        $settings_tabs[self::SETTINGS_TAB] = __('Accounting report', 'woo-accounting-report');
        return $settings_tabs;
    }

    public static function settings_tab($sections)
    {
        woocommerce_admin_fields(self::get_settings());
    }

    public static function update_settings()
    {
        woocommerce_update_options(self::get_settings());
    }

    /**
     * Get settings array.
     *
     * @param string $current_section Current section name.
     * @return array
     */
    public static function get_settings($current_section = '')
    {
        if  ('' === $current_section) {
            $settings = array(
                array(
                    'title' => __('General options', 'woo-accounting-report'),
                    'type' => 'title',
                    'desc' => '',
                    'id' => 'general_accounting_options',
                ),
                array(
                    'title' => __('Report country','woo-accounting-report'),
                    'css'      => 'min-width:150px;',
                    'default'  => 'generic',
                    'type'     => 'select',
                    'class'    => 'wc-enhanced-select',
                    'options'  => array(
                        'generic' => 'Generic report, works for most countries',
                    ),
                    'description' => __('Select the country where the report should be accounted in', 'woo-accounting-report'),
                    'desc_tip' => true,
                    'id' => 'woo_ar_report_version',
                ),
                array(
                    'title' => __('Base the report on status','woo-accounting-report'),
                    'css'      => 'min-width:150px;',
                    'default'  => 'date_completed',
                    'type'     => 'select',
                    'class'    => 'wc-enhanced-select',
                    'options'  => array(
                        'date_completed' => 'Completed',
                        'date_paid' => 'Paid',
                    ),
                    'description' => __('Base the report on when a transaction was set to "paid" status or the "completed" status', 'woo-accounting-report'),
                    'desc_tip' => true,
                    'id' => 'woo_ar_report_on_status',
                ),
                array(
                    'title' => __('Tax Class for refunds','woo-accounting-report'),
                    'css'      => 'min-width:150px;',
                    'default'  => '',
                    'type'     => 'select',
                    'class'    => 'wc-enhanced-select',
                    'options'  => wc_get_product_tax_class_options(),
                    'description' => __('Tax class to use for reverse calculation of tax on refunds without tax', 'woo-accounting-report'),
                    'desc_tip' => true,
                    'id' => 'woo_ar_reverse_tax_class',
                ),
                array(
                    'title' => __('Treat all sales as local','woo-accounting-report'),
                    'default' => '',
                    'type' => 'checkbox',
                    'id' => 'woo_ar_force_local',
                ),
                array(
                    'type' => 'sectionend',
                    'id' => 'general_accounting_options',
                ),
            );
        }
        return $settings;
    }

}

