<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/**
 * WC_Report_Accounting
 *
 * Text Domain:       woo-accounting-report
 * @author      BjornTech
 * @category    Admin
 * @package     WooCommerce/Admin/Reports
 * @version     1.0.0
 */
class WC_Report_Accounting_By_Date extends WC_Admin_Report
{

    private $sales_per_tax_class = array();
    private $total_sales_per_tax_class = array();
    private $total_sales = array();
    private $total_sales_vat = array();
    private $total_refunds = array();
    private $total_refunds_vat = array();
    private $total_shipping = array();
    private $total_shipping_vat = array();
    private $order_differences = array();
    private $sales_per_region = array();
    private $total_fees = array();
    private $total_fees_vat = array();
    private $tax_classes = array();
    private $site_currencies = array();
    private $multiple_tax_in_shipping = false;
    private $cc;

    /**
     * Get the legend for the main chart sidebar.
     *
     * @return array
     */
    public function get_chart_legend()
    {
        return array();
    }

    /**
     * Output an export link.
     */
    public function get_export_button()
    {

        $current_range = !empty($_GET['range']) ? sanitize_text_field($_GET['range']) : 'last_month';
        ?>
		<a
			href="#"
			download="report-<?php echo esc_attr($current_range); ?>-<?php echo date_i18n('Y-m-d', current_time('timestamp')); ?>.csv"
			class="export_csv"
			data-export="table"
		>
			<?php _e('Export CSV', 'woocommerce');?>
		</a>
		<?php
}

    /**
     * Output the report.
     */
    public function output_report()
    {

        $ranges = array(
            'year' => __('Year', 'woocommerce'),
            'last_month' => __('Last month', 'woocommerce'),
            'month' => __('This month', 'woocommerce'),
        );

        $current_range = !empty($_GET['range']) ? sanitize_text_field($_GET['range']) : 'last_month';

        if (!in_array($current_range, array('custom', 'year', 'last_month', 'month', '7day'))) {
            $current_range = 'last_month';
        }

        $this->check_current_range_nonce($current_range);
        $this->calculate_current_range($current_range);

        $hide_sidebar = true;

        include WC()->plugin_path() . '/includes/admin/views/html-report-by-date.php';
    }

    private function order_item_tax_class($order_item, $order)
    {
        $tax_class = $order_item->get_tax_class();
        $matched_tax_rates = WC_Tax::get_rates($tax_class);
        return number_format((reset($matched_tax_rates)['rate']), 0) . '%';
    }

    private function get_order_tax_classes($order)
    {
        $return_array = array();
        $tax_classes = $order->get_items_tax_classes();
        foreach ($tax_classes as $tax_class) {
            $matched_tax_rates = WC_Tax::get_rates($tax_class);
            $return_array[] = number_format((reset($matched_tax_rates)['rate']), 0) . '%';
        }
        return implode(', ', $return_array);
    }

    private function process_order_line_items($type, $order)
    {
        $order_currency = $order->get_currency();
        $order_items = $order->get_items();
        $tax_class = '0%';
        $order_taxes = $order->get_taxes();
        $order_items_amount = 0;

        foreach ($order_items as $order_item) {

            $order_item_tax = 0;
            $order_item_ex_tax = wc_format_decimal($order_item->get_total(), '');

            if (($tax_data = $order_item->get_taxes()) && wc_tax_enabled()) {

                foreach ($order_taxes as $tax_item) {

                    $tax_item_id = $tax_item->get_rate_id();
                    $tax_class = number_format(WC_Tax::_get_tax_rate($tax_item_id)['tax_rate'], 0) . '%';

                    $tax_item_total = array_key_exists($tax_item_id, $tax_data['total']) ? $tax_data['total'][$tax_item_id] : '';

                    if ('' !== $tax_item_total) {
                        $order_item_tax = wc_round_tax_total($tax_item_total);
                    }

                    $this->total_sales_per_tax_class_vat[$order_currency][$tax_class] = array_key_exists($tax_class, $this->total_sales_per_tax_class_vat[$order_currency]) ? $this->total_sales_per_tax_class_vat[$order_currency][$tax_class] + $order_item_tax : $order_item_tax;

                }

            }

            if (!in_array($tax_class, $this->tax_classes[$order_currency])) {
                $this->tax_classes[$order_currency][] = $tax_class;
            }

            $this->total_sales_per_tax_class[$order_currency][$tax_class] = array_key_exists($tax_class, $this->total_sales_per_tax_class[$order_currency]) ? $this->total_sales_per_tax_class[$order_currency][$tax_class] + $order_item_ex_tax : $order_item_ex_tax;

            $order_items_amount += $order_item_ex_tax + $order_item_tax;
        }

        return $order_items_amount;
    }

    private function process_order_refund($type, $order)
    {
        $order_currency = $order->get_currency();

        $order_item_tax = wc_round_tax_total($order->get_total_tax());
        $order_item_total = wc_format_decimal($order->get_total(), '');

        $order_item_ex_tax = $order_item_total - $order_item_tax;

        $tax_class = false;

        if ($order_item_tax == 0) {
            $tax_class = '0%';
        } else {
            $rates = WC_Tax::get_rates(get_option('woo_ar_reverse_tax_class'));
            $tax_class = number_format(reset($rates)['rate'], 0) . '%';
        }

        if (!in_array($tax_class, $this->tax_classes[$order_currency])) {
            $this->tax_classes[$order_currency][] = $tax_class;
        }
        $this->total_refunds[$order_currency][$tax_class] = array_key_exists($tax_class, $this->total_refunds[$order_currency]) ? $this->total_refunds[$order_currency][$tax_class] + $order_item_ex_tax : $order_item_ex_tax;
        $this->total_refunds_vat[$order_currency][$tax_class] = array_key_exists($tax_class, $this->total_refunds_vat[$order_currency]) ? $this->total_refunds_vat[$order_currency][$tax_class] + $order_item_tax : $order_item_tax;

        return $order_item_total;
    }

    private function process_order_fees($type, $order)
    {
        $order_currency = $order->get_currency();
        $order_items = $order->get_fees();
        $order_items_amount = 0;

        foreach ($order_items as $order_item) {

            $tax_class = $this->order_item_tax_class($order_item, $order);

            if (!in_array($tax_class, $this->tax_classes[$order_currency])) {
                $this->tax_classes[$order_currency][] = $tax_class;
            }

            $order_item_ex_tax = wc_format_decimal($order_item->get_total(), '');
            $order_item_tax = wc_round_tax_total($order_item->get_total_tax());
            $order_item_total = $order_item_ex_tax + $order_item_tax;

            $this->total_fees[$order_currency][$tax_class] += $order_item_ex_tax;
            $this->total_fees_vat[$order_currency][$tax_class] += $order_item_tax;

            $order_items_amount += $order_item_total;
        }
        return round($order_items_amount, wc_get_price_decimals());
    }

    private function process_order_shipping($type, $order)
    {

        $order_currency = $order->get_currency();

        $shipping_methods = $order->get_shipping_methods();
        $order_items_amount = 0;

        foreach ($shipping_methods as $shipping_method) {

            $shipping_tax_class = $shipping_method->get_tax_class();

            if ('inherit' === $shipping_tax_class) {
                $found_classes = array_intersect(array_merge(array(''), WC_Tax::get_tax_class_slugs()), $order->get_items_tax_classes());
                $shipping_tax_class = count($found_classes) ? current($found_classes) : false;
            }

            $tax_class = '0%';

            if ($order->get_type() == 'shop_order_refund') {
                $parent_id = $order->get_parent_id();
                $parent_order = new WC_Order($parent_id);
            }

            $rates = WC_Tax::get_rates($shipping_tax_class);
            $tax_class = number_format(reset($rates)['rate'], 0) . '%';

            if (!in_array($tax_class, $this->tax_classes[$order_currency])) {
                $this->tax_classes[$order_currency][] = $tax_class;
            }

            $shipping_item_ex_vat = wc_format_decimal($shipping_method->get_total(), '');
            $shipping_item_vat = wc_round_tax_total($shipping_method->get_total_tax());
            $shipping_item_total = $shipping_item_ex_vat + $shipping_item_vat;

            $this->total_shipping[$order_currency][$tax_class] = array_key_exists($tax_class, $this->total_shipping[$order_currency]) ? $this->total_shipping[$order_currency][$tax_class] += $shipping_item_ex_vat : $this->total_shipping[$order_currency][$tax_class] = $shipping_item_ex_vat;
            $this->total_shipping_vat[$order_currency][$tax_class] = array_key_exists($tax_class, $this->total_shipping_vat[$order_currency]) ? $this->total_shipping_vat[$order_currency][$tax_class] += $shipping_item_vat : $this->total_shipping_vat[$order_currency][$tax_class] = $shipping_item_vat;

            $order_items_amount += $shipping_item_total;
        }

        return round($order_items_amount, wc_get_price_decimals());
    }

    private function process_order($type, $order, $order_value)
    {
        $order_items_amount = 0;
        $order_difference = false;
        $order_currency = $order->get_currency();
        if (!in_array($order_currency, $this->site_currencies)) {
            array_push($this->site_currencies, $order_currency);
            $this->total_sales_per_tax_class[$order_currency] = array();
            $this->total_sales_per_tax_class[$order_currency]['0%'] = 0;
            $this->total_sales_per_tax_class_vat[$order_currency] = array();
            $this->total_sales_per_tax_class_vat[$order_currency]['0%'] = 0;
            $this->tax_classes[$order_currency] = array();
            $this->total_fees[$order_currency] = array();
            $this->total_fees[$order_currency]['0%'] = 0;
            $this->total_fees_vat[$order_currency] = array();
            $this->total_fees_vat[$order_currency]['0%'] = 0;
            $this->total_shipping[$order_currency] = array();
            $this->total_shipping[$order_currency]['0%'] = 0;
            $this->total_shipping_vat[$order_currency] = array();
            $this->total_shipping_vat[$order_currency]['0%'] = 0;
            $this->total_refunds[$order_currency] = array();
            $this->total_refunds[$order_currency]['0%'] = 0;
            $this->total_refunds_vat[$order_currency] = array();
            $this->total_refunds_vat[$order_currency]['0%'] = 0;
            $this->sales_per_region[$order_currency] = array();
        }
        if ($order->get_type() == 'shop_order_refund') {
            $order_items_amount += $this->process_order_refund($type, $order);
        } else {
            $order_items_amount += $this->process_order_line_items($type, $order);
            $order_items_amount += $this->process_order_fees($type, $order);
            $order_items_amount += $this->process_order_shipping($type, $order);
        }

        if ($order_items_amount != $order_value) {

            $diff = $order_value - $order_items_amount;
            if (floatval(round($diff, wc_get_price_decimals())) != 0) {
                if ($order->get_type() == 'shop_order_refund') {
                    $this->total_refunds[$order_currency]['unknown'] = array_key_exists('unknown', $this->total_refunds[$order_currency]) ? $this->total_refunds[$order_currency]['unknown'] += $diff : $this->total_refunds[$order_currency]['unknown'] = $diff;
                } else {
                    $this->total_sales_per_tax_class[$order_currency]['unknown'] = array_key_exists('unknown', $this->total_sales_per_tax_class[$order_currency]) ? $this->total_sales_per_tax_class[$order_currency]['unknown'] += $diff : $this->total_sales_per_tax_class[$order_currency]['unknown'] = $diff;
                }
                $order_difference = sprintf('Difference in order %s, order value is %s but the order items sum is %s making a difference of %s', $order->get_id(), $order_value, $order_items_amount, $diff);
            }
        }

        if (!array_key_exists($type, $this->sales_per_region[$order_currency])) {
            $this->sales_per_region[$order_currency][$type] = array();
        }

        $this->sales_per_region[$order_currency][$type]['total'] = array_key_exists('total', $this->sales_per_region[$order_currency][$type]) ? $this->sales_per_region[$order_currency][$type]['total'] + $order->get_total() : $order->get_total();
        $this->sales_per_region[$order_currency][$type]['tax'] = array_key_exists('tax', $this->sales_per_region[$order_currency][$type]) ? $this->sales_per_region[$order_currency][$type]['tax'] + $order->get_total_tax() : $order->get_total_tax();
        return $order_difference;
    }

    public function get_exchage_rates($date = 'latest', $base = false)
    {

        $args = $base ? array('base' => $base) : array();

        $response = wp_remote_get('https://api.exchangeratesapi.io/' . $date, $args);

        if (is_wp_error($response)) {
            WC_AR()->log->add(print_r($response, true));
            return false;
        } else {
            if (($http_code = wp_remote_retrieve_response_code($response)) != 200) {
                WC_AR()->log->add(print_r($http_code, true));
                return false;
            }
            $body = wp_remote_retrieve_body($response);
            return json_decode($body);
        }

    }

    public function get_val($value_array, $value_key) {
        if (array_key_exists($value_key,$value_array)) {
            return $value_array[$value_key];
        } 
        return 0;
    }
    
    /**
     * Get the main chart.
     */
    public function get_main_chart()
    {
        $base_currency = get_woocommerce_currency();
        date_default_timezone_set(get_option('timezone_string'));
        $my_country = WC()->countries->get_base_country();
        $only_local = get_option('woo_ar_force_local') == 'yes' ? true : false;
        $from_timestamp = strtotime(date('m/d/Y 00:00:01', $this->start_date));
        $to_timestamp = strtotime(date('m/d/Y 23:59:59', $this->end_date));
        $period = $from_timestamp . '...' . $to_timestamp;
        $base_on_status = get_option('woo_ar_report_on_status', 'date_completed');

        $payments = wc_get_orders(array(
            $base_on_status => $period,
            'type' => 'shop_order',
            'limit' => -1,
        ));

        $refunds = wc_get_orders(array(
            'type' => 'shop_order_refund',
            'date_created' => $period,
            'limit' => -1,
        ));

        $orders = array_merge($payments, $refunds);

        // make shure that orders being fully refunded before they get to the completed-status is also included (to match with the refund)
        if ('date_completed' == $base_on_status) {

            $already_got_ids = array();
            foreach ($orders as $order) {
                array_push($already_got_ids, $order->get_id());
            }

            $extras = wc_get_orders(array(
                'date_paid' => $period,
                'type' => 'shop_order',
                'status' => 'refunded',
                'exclude' => $already_got_ids,
                'limit' => -1,
            ));

            // Only include the fully refunded orders that never got to the completed stage until refunded
            $refunded_before_completion = array();
            foreach ($extras as $extra) {
                if (!$extra->get_date_completed()) {
                    array_push($refunded_before_completion, $extra);
                }
            }

            $orders = array_merge($orders, $refunded_before_completion);

        }

        $countries = new WC_Countries();

        $payment_methods = array();
        $payment_method_titles = array();

        $non_eu_sales = array();
        $all_orders = array();
        $completed_date = '';
        $stripe_fees = 0;

        $parent_order = null;
        $eu_private_sales = array();

        $parent_id = 0;
        $total_payments = array();

        $tax_rates_array = WC_Tax::find_rates(array(
            'country' => $my_country,
            'state' => WC()->countries->get_base_state(),
            'postcode' => WC()->countries->get_base_postcode(),
            'city' => WC()->countries->get_base_city(),
            'tax_class' => get_option('woo_ar_reverse_tax_class'),
        ));
        $tax_rates = reset($tax_rates_array);
        $accounting_reverse_calculate_tax_class = key($tax_rates_array);

        foreach ($orders as $order) {

            $order_id = $order->get_id();
            $order_tax_rates = 'n/a';
            $order_value = $order->get_total();
            $tax_value = $order->get_total_tax();
            $order_type = $order->get_type();

            if ($order_type == 'shop_order_refund') {
                $parent_id = $order->get_parent_id();
                $parent_order = new WC_Order($parent_id);
                $payment_method = $parent_order->get_payment_method();
                $payment_method_titles[$payment_method] = $parent_order->get_payment_method_title();
                $billing_country = $parent_order->get_billing_country();
                $eu_vat_number_validated = get_post_meta($parent_id, '_vat_number_is_valid', true) == 'true' ? true : false;
                $customer_name = $parent_order->get_billing_company() ? $parent_order->get_billing_company() : $parent_order->get_billing_first_name() . ' ' . $parent_order->get_billing_last_name();
                $order_currency = $parent_order->get_currency();
                $completed_date = 'n/a';
                if (($order_value != 0) && ($tax_value == 0)) {
                    $tax_array = WC_Tax::calc_inclusive_tax($order_value, $tax_rates_array);
                    foreach ($tax_array as $tax) {
                        $tax_value += $tax;
                    }
                }
            } else {
                $parent_order = null;
                $order_tax_rates = $this->get_order_tax_classes($order);
                $payment_method = $order->get_payment_method();
                $payment_method_titles[$payment_method] = $order->get_payment_method_title();
                $billing_country = $order->get_billing_country();
                $eu_vat_number_validated = get_post_meta($order_id, '_vat_number_is_valid', true) == 'true' ? true : false;
                $customer_name = $order->get_billing_company() ? $order->get_billing_company() : $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
                $order_currency = $order->get_currency();
                $completed_date = $order->get_date_completed();

            }
            if (!array_key_exists($order_currency, $total_payments)) {
                $total_payments[$order_currency] = 0;
            }

            $stripe_fee = get_post_meta($order_id, '_stripe_fee', true);
            $stripe_fees += is_numeric($stripe_fee) ? $stripe_fee : 0;

            if (!array_key_exists($payment_method, $payment_methods)) {
                $payment_methods[$payment_method] = array();
            }
            $payment_methods[$payment_method][$order_currency] = array_key_exists($order_currency, $payment_methods[$payment_method]) ? $payment_methods[$payment_method][$order_currency] + $order_value : $order_value;
            $total_payments[$order_currency] = $total_payments[$order_currency] + $order_value;

            $order_fees = $order->get_fees();

            $sort_criteria = $order_type == 'shop_order_refund' ? $parent_order->get_order_number() : $order->get_order_number();

            $all_orders[$billing_country][] = array(
                'number' => $order_type == 'shop_order_refund' ? $parent_order->get_order_number() : $order->get_order_number(),
                'id' => $order->get_id(),
                'value' => $order_value,
                'tax_value' => $tax_value,
                'currency' => $order->get_currency(),
                'tax_rates' => $order_tax_rates,
                'eu_vat_number_validated' => $eu_vat_number_validated,
                'country' => $billing_country,
                'payment_method' => $payment_method,
                'customer_name' => $customer_name,
                'date_created' => $order->get_date_created(),
                'date_modified' => $order->get_date_modified(),
                'date_paid' => $order_type == 'shop_order_refund' ? 'n/a' : $order->get_date_paid(),
                'date_completed' => $completed_date,
                'shipping' => $order->get_shipping_total(),
                'customer_vat_number' => get_post_meta($order_id, '_vat_number', true),
                'stripe_fee' => $stripe_fee,
            );

            $order_difference = false;
            if (($billing_country == '') || ($billing_country == $my_country) || $only_local) {

                $order_difference = $this->process_order('local', $order, $order_value);

            } elseif (in_array($billing_country, $countries->get_european_union_countries())) {
                if ($eu_vat_number_validated) {
                    $order_difference = $this->process_order('eu-vat-exempt', $order, $order_value);
                } else {
                    $order_difference = $this->process_order('eu', $order, $order_value);
                }

            } else {
                $order_difference = $this->process_order('non-eu', $order, $order_value);
            }

            if ($order_difference) {
                $this->order_differences[] = $order_difference;
            }
        }

        foreach ($all_orders as $key => $order_country) {
            asort($all_orders[$key]);
        }

        $exchange_response = $this->get_exchage_rates('latest', $base_currency);
        $exchange_rates = $exchange_response->rates;

        ?>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <style>
                    table { border: 1px solid #000; width: 100%; }
                    table td, table th { border: 1px solid #000; padding: 6px; }
                </style>
            </head>
            <body>
                <div class="widefat">
                    <div class="row">
                        <h1><?php _e('Accounting report', 'woo-accounting-report') . ' ' . date('Y-m-d', $this->start_date) . '-' . date('Y-m-d', $this->end_date);?></h1>
                    </div>
                </div>
                <?php foreach ($this->site_currencies as $report_currency) {?>
                    <?php $this->cc = count($this->site_currencies) != 1 || $base_currency != $report_currency;
            $exchange_rate = $exchange_rates->{$report_currency}?>
                    <div>
                        <div class="widefat">
                            <div class="row"
                                <h2><u><?php _e(sprintf('Total sales %s', $report_currency), 'woo-accounting-report')?></u></h2>
                                <table cellspacing="0" cellpadding="2">
                                    <thead>
                                        <tr>
                                            <th scope="col" style="text-align:left;"><?php _e('Type (VAT-percentage)', 'woo-accounting-report');?></th>
                                            <th scope="col" style="text-align:left;"><?php _e(sprintf('Total %s sales excl. VAT', $report_currency), 'woo-accounting-report');?></th>
                                            <th scope="col" style="text-align:left;"><?php _e('VAT', 'woo-accounting-report');?></th>
                                            <th scope="col" style="text-align:left;"><?php _e(sprintf('Total %s sales incl. VAT', $report_currency), 'woo-accounting-report');?></th>
                                            <?php if ($this->cc) {?>
                                            <th scope="col" style="text-align:left;"><?php _e(sprintf('Total sales in %s', $base_currency), 'woo-accounting-report');?></th>
                                            <?php }?>
                                        </tr>
                                    </thead>
                                    <tbody>
                                    <?php $grand_total = 0;
            $grand_total_vat = 0;
            $grand_sub_total = 0;
            $grand_sub_total_currency = 0;
            foreach ($this->tax_classes[$report_currency] as $tax_class) {

                $total = $this->total_sales_per_tax_class[$report_currency][$tax_class] + $this->total_sales_per_tax_class_vat[$report_currency][$tax_class] +
                $this->total_refunds[$report_currency][$tax_class] + $this->total_refunds_vat[$report_currency][$tax_class] +
                $this->total_fees[$report_currency][$tax_class] + $this->total_fees_vat[$report_currency][$tax_class] +
                $this->total_shipping[$report_currency][$tax_class] + $this->total_shipping_vat[$report_currency][$tax_class];
                $total_vat = $this->total_sales_per_tax_class_vat[$report_currency][$tax_class] + $this->total_refunds_vat[$report_currency][$tax_class] + $this->total_shipping_vat[$report_currency][$tax_class] + $this->total_fees_vat[$report_currency][$tax_class];
                $sub_total = $this->total_sales_per_tax_class[$report_currency][$tax_class] + $this->total_refunds[$report_currency][$tax_class] + $this->total_fees[$report_currency][$tax_class] + $this->total_shipping[$report_currency][$tax_class];
                $sub_total_currency = $sub_total * $exchange_rate;

                $grand_total += $total;
                $grand_total_vat += $total_vat;
                $grand_sub_total += $sub_total;
                $grand_sub_total_currency += $sub_total_currency;
                ?>
                <tr>
                    <td align="left"><?php echo _e('Sales ', 'woo-accounting-report') . $tax_class; ?></td>
                    <td align="right"><?php echo number_format($this->total_sales_per_tax_class[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_sales_per_tax_class_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_sales_per_tax_class[$report_currency][$tax_class] + $this->total_sales_per_tax_class_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <?php if ($this->cc) {?>
                    <td align="right"><?php echo number_format(($this->total_sales_per_tax_class[$report_currency][$tax_class] + $this->total_sales_per_tax_class_vat[$report_currency][$tax_class]) * $exchange_rate, 2, ',', ' '); ?></td>
                    <?php }?>
                </tr>
                <tr>
                <td align="left"><?php echo _e('Refunds ', 'woo-accounting-report') . $tax_class; ?></td>
                <td align="right"><?php echo number_format($this->total_refunds[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_refunds_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_refunds[$report_currency][$tax_class] + $this->total_refunds_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <?php if ($this->cc) {?>
                    <td align="right"><?php echo number_format(($this->total_refunds[$report_currency][$tax_class] + $this->total_refunds_vat[$report_currency][$tax_class]) * $exchange_rate, 2, ',', ' '); ?></td>
                    <?php }?>
                </tr>
                <tr>
                    <td align="left"><?php echo _e('Fees ', 'woo-accounting-report') . $tax_class; ?></td>
                    <td align="right"><?php echo number_format($this->total_fees[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_fees_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_fees[$report_currency][$tax_class] + $this->total_fees_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <?php if ($this->cc) {?>
                    <td align="right"><?php echo number_format(($this->total_fees[$report_currency][$tax_class] + $this->total_fees_vat[$report_currency][$tax_class]) * $exchange_rate, 2, ',', ' '); ?></td>
                    <?php }?>
                </tr>
                <tr>
                    <td align="left"><?php echo _e('Shipping ', 'woo-accounting-report') . $tax_class; ?></td>
                    <td align="right"><?php echo number_format($this->total_shipping[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_shipping_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($this->total_shipping[$report_currency][$tax_class] + $this->total_shipping_vat[$report_currency][$tax_class], 2, ',', ' '); ?></td>
                    <?php if ($this->cc) {?>
                    <td align="right"><?php echo number_format(($this->total_shipping[$report_currency][$tax_class] + $this->total_shipping_vat[$report_currency][$tax_class]) * $exchange_rate, 2, ',', ' '); ?></td>
                    <?php }?>
                </tr>
                <tr>
                    <td align="left"><?php echo _e('Total sales incl shipping and charged fees ', 'woo-accounting-report') . $tax_class; ?></td>
                    <td align="right"><?php echo number_format($sub_total, 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($total_vat, 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($total, 2, ',', ' '); ?></td>
                    <?php if ($this->cc) {?>
                    <td align="right"><?php echo number_format($sub_total_currency, 2, ',', ' '); ?></td>
                    <?php }?>
                </tr>
            <?php }?>
        <?php }?>
                <tr>
                    <td align="left"><?php echo _e('All sales incl shipping and charged fees ', 'woo-accounting-report'); ?></td>
                <?php if ($this->cc) {?>
                    <td align="right"></td>
                    <td align="right"></td>
                    <td align="right"></td>
                    <td align="right"><?php echo number_format($grand_sub_total_currency, 2, ',', ' '); ?></td>
                <?php } else {?>
                    <td align="right"><?php echo number_format($grand_sub_total, 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($grand_total_vat, 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($grand_total, 2, ',', ' '); ?></td>
                    <?php }?>
                </tr>
        </tbody>

            </table>
            </div>
            </div>
            </div>

            <div>
            <div class="widefat">
            <div class="row">
            <h2><u><?php _e('Total sales per region', 'woo-accounting-report')?></u></h2>

            <table cellspacing="0" cellpadding="2">
            <thead>
                <tr>
                <th scope="col" style="text-align:left;"><?php _e('Region', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Total sales incl. VAT', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('VAT', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Total sales excl. VAT', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Currency', 'woo-accounting-report');?></th>
                </tr>
            </thead>
            <?php
foreach ($this->site_currencies as $report_currency) {
            foreach ($this->sales_per_region[$report_currency] as $region => $amount) {
                ?>
                <tbody>
                <tr>
                    <td align="left"><?php echo $region; ?></td>
                    <td align="right"><?php echo number_format($amount['total'], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($amount['tax'], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($amount['total'] - $amount['tax'], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo $report_currency; ?></td>
                </tr>
        </tbody>
        <?php
}
        }
        ?>
        </table>
            </div>
            </div>
            </div>

            <div>
            <div class="widefat">
            <div class="row">
            <h2><u><?php _e('Methods of payment', 'woo-accounting-report')?></u></h2>
            <table cellspacing="0" cellpadding="2">
            <thead>
                <tr>
                <th scope="col" style="text-align:left;"><?php _e('Payment method', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Currency', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Amount', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Fee', 'woo-accounting-report');?></th>
                </tr>
            </thead>
            <tbody>
                <?php
foreach ($payment_methods as $payment_method => $order_currencys) {
            foreach ($order_currencys as $currency_key => $order_currency) {
                ?>
                <tr>
                    <td><?php echo empty($payment_method_titles[$payment_method]) ? str_replace('_', ' ', ucfirst($payment_method)) : $payment_method_titles[$payment_method]; ?></td>
                    <td><?php echo $currency_key; ?></td>
                    <td align="right"><?php echo number_format($order_currency, 2, ',', ' '); ?></td>
                    <?php if ($payment_method == 'stripe') {
                    ?><td align="right"><?php echo number_format($stripe_fees, 2, ',', ' '); ?></td>  <?php
} else {
                    ?><td><?php echo 'n/a'; ?></td>  <?php
}
                ?>
                    </tr>
                <?php
}

        }

        ?>			</tbody>

            </table>
            </div>
            </div>
            </div>




                <div class="widefat">
                <div class="row">
                <h2><u><?php _e('All orders', 'woo-accounting-report')?></u></h2>
                <table cellspacing="0" cellpadding="2">
                <thead>
                <tr>

                <th scope="col" style="text-align:left;"><?php _e('Order date', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Order number', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Id', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Buyer name', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Country', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Payment method', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Stripe fee', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Currency', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Value ex. VAT', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('VAT', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('VAT rate', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Shipping', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Total amount', 'woo-accounting-report');?></th>
                <th scope="col" style="text-align:left;"><?php _e('Corporate VAT number', 'woo-accounting-report');?></th>
                </tr>
                </thead>
                <tbody>
                <?php
$grand_total_ex_vat = 0;
        $grand_total_vat = 0;
        $grand_total_shipping = 0;
        $grand_total = 0;
        if (isset($all_orders)) {

            foreach ($all_orders as $country => $sort_criteria) {
                $total_ex_vat = 0;
                $total_vat = 0;
                $total_shipping = 0;
                $total = 0;

                foreach ($sort_criteria as $order) {
                    $total_ex_vat += $order['value'] - $order['tax_value'];
                    $total_vat += $order['tax_value'];
                    $total_shipping += $order['shipping'];
                    $total += $order['value'];

                    ?>
                <tr>
                <td><?php echo substr($order['date_modified'], 0, 10); ?></td>
                    <td><?php echo $order['number']; ?></td>
                    <td><?php echo $order['id']; ?></td>
                    <td><?php echo $order['customer_name']; ?></td>
                    <td><?php echo $order['country']; ?></td>
                    <td><?php echo empty($payment_method_titles[$order['payment_method']]) ? str_replace('_', ' ', ucfirst($order['payment_method'])) : $payment_method_titles[$order['payment_method']]; ?></td>
                    <td align="right"><?php echo $order['stripe_fee']; ?></td>
                    <td><?php echo $order['currency']; ?></td>
                    <td align="right"><?php echo number_format($order['value'] - $order['tax_value'], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($order['tax_value'], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo $order['tax_rates']; ?></td>
                    <td align="right"><?php echo number_format($order['shipping'], 2, ',', ' '); ?></td>
                    <td align="right"><?php echo number_format($order['value'], 2, ',', ' '); ?></td>
                    <td><?php echo $order['customer_vat_number']; ?></td>
                    </tr>
                <?php
}
                $grand_total_ex_vat += $total_ex_vat;
                $grand_total_vat += $total_vat;
                $grand_total_shipping += $total_shipping;
                $grand_total += $total;

                ?>
<tr>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo 'Total ' . $country; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td align="right"><?php echo number_format($total_ex_vat, 2, ',', ' '); ?></td>
    <td align="right"><?php echo number_format($total_vat, 2, ',', ' '); ?></td>
    <td><?php echo ''; ?></td>
    <td align="right"><?php echo number_format($total_shipping, 2, ',', ' '); ?></td>
    <td align="right"><?php echo number_format($total, 2, ',', ' '); ?></td>
    <td><?php echo ''; ?></td>
    </tr>
<?php
}
            ?>
<tr>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo 'Grand total ' ?></td>
    <td><?php echo ''; ?></td>
    <td><?php echo ''; ?></td>
    <td align="right"><?php echo number_format($grand_total_ex_vat, 2, ',', ' '); ?></td>
    <td align="right"><?php echo number_format($grand_total_vat, 2, ',', ' '); ?></td>
    <td><?php echo ''; ?></td>
    <td align="right"><?php echo number_format($grand_total_shipping, 2, ',', ' '); ?></td>
    <td align="right"><?php echo number_format($grand_total, 2, ',', ' '); ?></td>
    <td><?php echo ''; ?></td>
    </tr>
<?php
}
        ?>			</tbody>
                </table>
                </div>
                </div>

                <?php if (count($this->order_differences) > 0) {include WC_AR()->includes_dir . 'html/order-differences.php';}?>

            </body>
            <?php

    }
}
