<?php

/**
 * The main plugin file for WooCommerce Accounting Report.
 *
 * This file is included during the WordPress bootstrap process if the plugin is active.
 *
 * @package   WooCommerce_Accounting_Report
 * @author    BjornTech <info@bjorntech.se>
 * @license   GPL-3.0
 * @link      https://bjorntech.se
 * @copyright 2018 BjornTech AB
 *
 * @wordpress-plugin
 * Plugin Name:       WooCommerce Accounting Report
 * Plugin URI:        https://www.bjorntech.se/accountingreport
 * Description:       Generates Accounting reports
 * Version:           1.1.3
 * Author:            BjornTech
 * Author URI:        https://bjorntech.se
 * Text Domain:       woo-accounting-report
 * Domain Path:       /languages
 *
 * WC requires at least: 4.0
 * WC tested up to: 4.4
 *
 * Copyright:         2018-2020 BjornTech AB
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('ABSPATH') || exit;

/**
 *    WC_Accounting_Report
 *
 */
class WC_Accounting_Report_Plugin
{
    /**
     * Plugin data
     */
    const NAME = 'WooCommerce Accounting Report';
    const SCRIPT_HANDLE = 'woo-accounting-report';
    const PLUGIN_FILE = __FILE__;

    public $plugin_basename;
    public $includes_dir;
    public $assets_url;

    /**
     * Plugin helper classes
     */
    public $log;
    public $payment_handler;

    /**
     *    $instance
     *
     * @var    mixed
     * @access public
     * @static
     */
    public static $instance = null;
    public $report_country;

    /**
     * Init and hook in the integration.
     **/
    public function __construct()
    {
        $this->plugin_basename = plugin_basename(self::PLUGIN_FILE);
        $this->includes_dir = plugin_dir_path(self::PLUGIN_FILE) . 'includes/';
        $this->assets_url = trailingslashit(plugins_url('assets', self::PLUGIN_FILE));

        $this->includes();
        $this->scripts_and_styles();

        add_action('plugins_loaded', array($this, 'load_textdomain'), 9);
        add_action('plugins_loaded', array($this, 'maybe_load_plugin'));

        $this->report_country = get_option('woo_ar_report_version','generic');

    }

    public function scripts_and_styles()
    {
        //   wp_enqueue_style( 'slider', $this->includes_dir . '/css/slider.css',false,'1.1','all');
    }

    public function load_textdomain()
    {
        load_plugin_textdomain('woo-accounting-report', false, dirname($this->plugin_basename) . '/languages');
    }

    private function includes()
    {
        require_once $this->includes_dir . 'class-woo-accounting-report-exception.php';
        require_once $this->includes_dir . 'class-woo-accounting-report-log.php';
        require_once $this->includes_dir . 'admin/class-woo-accounting-report-settings.php';
    }

    public function maybe_load_plugin()
    {

        if (!class_exists('WooCommerce')) {
            return;
        }

        add_action('init', array($this, 'init'));
    }

    public function init()
    {
        new WC_Admin_Accounting_Report_Settings();
        $this->log = new WC_Accounting_Report_Log();
 
        add_filter( 'woocommerce_admin_reports', array($this, 'add_report_to_menu') );
        add_filter( 'wc_admin_reports_path',array($this,'set_report_path'), 10,3);
    }

    public function set_report_path($path, $name, $class) {
        if ($name == 'accounting-by-date') {
            $path = $this->includes_dir . 'class-woo-accounting-report-'.$this->report_country.'.php';
        }
        return $path;
    }

    public function add_report_to_menu($reports) {
        $reports['accounting'] = array(
            'title'   => __( 'Accounting report', 'woo-accounting-report' ),
            'reports' => array(
                'accounting_by_date' => array(
                    'title'       => __( 'Accounting by date', 'woo-accounting-report' ),
                    'description' => '',
                    'hide_title'  => true,
                    'callback'    => array( 'WC_Admin_Reports', 'get_report' ),
                ),
            ),
        );
        return $reports;
    }
    /**
     * Returns a new instance of self, if it does not already exist.
     *
     * @access public
     * @static
     * @return WC_Accounting_Report_Plugin
     */
    public static function instance()
    {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

}

/**
 * Make the object available for later use
 *
 * @return WC_Accounting_Report_Plugin
 */
function WC_AR()
{
    return WC_Accounting_Report_Plugin::instance();
}

/**
 * Instantiate
 */
$wc_accounting_report = WC_AR();
